==> marketplace-constants-0.1.4.1.tar.gz: marketplace-constants-0.1.4.1/mpconstants/regions/es_AR.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afganist\\u00E1n',
 u'ag': u'Antigua y Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antillas Holandesas',
 u'ao': u'Angola',
 u'aq': u'Ant\\u00E1rtida',
 u'ar': u'Argentina',
 u'as': u'Samoa Americana',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'\\u00C5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'B\\u00E9lgica',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'San Bartolom\xe9',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Isla Bouvet',
 u'bw': u'Botswana',
 u'by': u'Bielorrusia',
 u'bz': u'Belice',
 u'ca': u'Canad\\u00E1',
 u'cc': u'Islas Cocos (Keeling)',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Rep\\u00FAblica Centro Africana',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Suiza',
 u'ci': u'Costa de Marfil',
 u'ck': u'Islas Cook',
 u'cl': u'Chile',
 u'cm': u'Camer\\u00FAn',
 u'cn': u'China',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cabo Verde',
 u'cx': u'Isla Navidad',
 u'cy': u'Chipre',
 u'cz': u'Rep\\u00FAblica Checa',
 u'de': u'Alemania',
 u'dj': u'Djibouti',
 u'dk': u'Dinamarca',
 u'dm': u'Dominica',
 u'do': u'Rep\\u00FAblica Dominicana',
 u'dz': u'Argelia',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Egipto',
 u'eh': u'Sahara Occidental',
 u'er': u'Eritrea',
 u'es': u'Espa\\u00F1a',
 u'et': u'Etiop\\u00EDa',
 u'fi': u'Finlandia',
 u'fj': u'Fiji',
 u'fk': u'Islas Malvinas',
 u'fm': u'Micronesia',
 u'fo': u'Islas Faroe',
 u'fr': u'Francia',
 u'ga': u'Gab\\u00F3n',
 u'gb': u'Reino Unido',
 u'gd': u'Granada',
 u'ge': u'Georgia',
 u'gf': u'Guayana Francesa',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Groenlandia',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadalupe',
 u'gq': u'Guinea Ecuatorial',
 u'gr': u'Grecia',
 u'gs': u'Islas Georgia y Sandwich del Sur',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Croacia',
 u'ht': u'Hait\\u00ED',
 u'hu': u'Hungr\\u00EDa',
 u'id': u'Indonesia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'India',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'Irak',
 u'ir': u'Ir\\u00E1n',
 u'is': u'Islandia',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordania',
 u'jp': u'Jap\\u00F3n',
 u'ke': u'Kenia',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Camboya',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'Corea del Norte',
 u'kr': u'Corea del Sur',
 u'kw': u'Kuwait',
 u'ky': u'Islas Caim\\u00E1n',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'L\\u00EDbano',
 u'lc': u'Santa Luc\\u00EDa',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lituania',
 u'lu': u'Luxemburgo',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Marruecos',
 u'mc': u'M\\u00F3naco',
 u'md': u'Moldova',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Islas Marshall',
 u'mk': u'Macedonia, Ex-Rep\\u00FAblica de',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricio',
 u'mv': u'Maldivas',
 u'mw': u'Malawi',
 u'mx': u'M\\u00E9xico',
 u'my': u'Malasia',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'Nueva Caledonia',
 u'ne': u'N\\u00EDger',
 u'nf': u'Isla Norfolk',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Holanda',
 u'no': u'Noruega',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Nuev Zelanda',
 u'om': u'Oman',
 u'pa': u'Panam\\u00E1',
 u'pe': u'Per\\u00FA',
 u'pf': u'Polinesia Francesa',
 u'pg': u'Pap\\u00FAa Nueva Guinea',
 u'ph': u'Filipinas',
 u'pk': u'Pakist\\u00E1n',
 u'pl': u'Polonia',
 u'pm': u'San Pedro y Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Territorio Palestino Ocupado',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Rumania',
 u'rs': u'Serbia',
 u'ru': u'Federaci\\u00F3n Rusa',
 u'rw': u'Rwanda',
 u'sa': u'Arabia Saudita',
 u'sb': u'Islas Solomon',
 u'sc': u'Seychelles',
 u'sd': u'Sud\\u00E1n',
 u'se': u'Suecia',
 u'sg': u'Singapur',
 u'sh': u'Santa Helena',
 u'si': u'Eslovenia',
 u'sj': u'Svalbard y Jan Mayen',
 u'sk': u'Eslovaquia',
 u'sl': u'Sierra Leona',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somal\\u00EDa',
 u'sr': u'Surinam',
 u'st': u'Sao Tome y Principe',
 u'sv': u'El Salvador',
 u'sy': u'Siria',
 u'sz': u'Swazilandia',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'Tailandia',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenist\\u00E1n',
 u'tn': u'T\\u00FAnez',
 u'to': u'Tonga',
 u'tr': u'Turqu\\u00EDa',
 u'tt': u'Trinidad y Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ucrania',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'Estados Unidos',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vaticano',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis y Futuna',
 u'ws': u'Samoa',
 u'ye': u'Yemen',
 u'yt': u'Mayotte',
 u'za': u'Sud\\u00E1frica',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.3.0.tar.gz: marketplace-constants-0.3.0/mpconstants/regions/es_AR.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afganist\xe1n',
 u'ag': u'Antigua y Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antillas Holandesas',
 u'ao': u'Angola',
 u'aq': u'Ant\xe1rtida',
 u'ar': u'Argentina',
 u'as': u'Samoa Americana',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'B\xe9lgica',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'San Bartolom\xe9',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Isla Bouvet',
 u'bw': u'Botswana',
 u'by': u'Bielorrusia',
 u'bz': u'Belice',
 u'ca': u'Canad\xe1',
 u'cc': u'Islas Cocos (Keeling)',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Rep\xfablica Centro Africana',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Suiza',
 u'ci': u'Costa de Marfil',
 u'ck': u'Islas Cook',
 u'cl': u'Chile',
 u'cm': u'Camer\xfan',
 u'cn': u'China',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cabo Verde',
 u'cx': u'Isla Navidad',
 u'cy': u'Chipre',
 u'cz': u'Rep\xfablica Checa',
 u'de': u'Alemania',
 u'dj': u'Djibouti',
 u'dk': u'Dinamarca',
 u'dm': u'Dominica',
 u'do': u'Rep\xfablica Dominicana',
 u'dz': u'Argelia',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Egipto',
 u'eh': u'Sahara Occidental',
 u'er': u'Eritrea',
 u'es': u'Espa\xf1a',
 u'et': u'Etiop\xeda',
 u'fi': u'Finlandia',
 u'fj': u'Fiji',
 u'fk': u'Islas Malvinas',
 u'fm': u'Micronesia',
 u'fo': u'Islas Faroe',
 u'fr': u'Francia',
 u'ga': u'Gab\xf3n',
 u'gb': u'Reino Unido',
 u'gd': u'Granada',
 u'ge': u'Georgia',
 u'gf': u'Guayana Francesa',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Groenlandia',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadalupe',
 u'gq': u'Guinea Ecuatorial',
 u'gr': u'Grecia',
 u'gs': u'Islas Georgia y Sandwich del Sur',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Croacia',
 u'ht': u'Hait\xed',
 u'hu': u'Hungr\xeda',
 u'id': u'Indonesia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'India',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'Irak',
 u'ir': u'Ir\xe1n',
 u'is': u'Islandia',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordania',
 u'jp': u'Jap\xf3n',
 u'ke': u'Kenia',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Camboya',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'Corea del Norte',
 u'kr': u'Corea del Sur',
 u'kw': u'Kuwait',
 u'ky': u'Islas Caim\xe1n',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'L\xedbano',
 u'lc': u'Santa Luc\xeda',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lituania',
 u'lu': u'Luxemburgo',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Marruecos',
 u'mc': u'M\xf3naco',
 u'md': u'Moldova',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Islas Marshall',
 u'mk': u'Macedonia, Ex-Rep\xfablica de',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricio',
 u'mv': u'Maldivas',
 u'mw': u'Malawi',
 u'mx': u'M\xe9xico',
 u'my': u'Malasia',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'Nueva Caledonia',
 u'ne': u'N\xedger',
 u'nf': u'Isla Norfolk',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Holanda',
 u'no': u'Noruega',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Nuev Zelanda',
 u'om': u'Oman',
 u'pa': u'Panam\xe1',
 u'pe': u'Per\xfa',
 u'pf': u'Polinesia Francesa',
 u'pg': u'Pap\xfaa Nueva Guinea',
 u'ph': u'Filipinas',
 u'pk': u'Pakist\xe1n',
 u'pl': u'Polonia',
 u'pm': u'San Pedro y Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Territorio Palestino Ocupado',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Rumania',
 u'rs': u'Serbia',
 u'ru': u'Federaci\xf3n Rusa',
 u'rw': u'Rwanda',
 u'sa': u'Arabia Saudita',
 u'sb': u'Islas Solomon',
 u'sc': u'Seychelles',
 u'sd': u'Sud\xe1n',
 u'se': u'Suecia',
 u'sg': u'Singapur',
 u'sh': u'Santa Helena',
 u'si': u'Eslovenia',
 u'sj': u'Svalbard y Jan Mayen',
 u'sk': u'Eslovaquia',
 u'sl': u'Sierra Leona',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somal\xeda',
 u'sr': u'Surinam',
 u'st': u'Sao Tome y Principe',
 u'sv': u'El Salvador',
 u'sy': u'Siria',
 u'sz': u'Swazilandia',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'Tailandia',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenist\xe1n',
 u'tn': u'T\xfanez',
 u'to': u'Tonga',
 u'tr': u'Turqu\xeda',
 u'tt': u'Trinidad y Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ucrania',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'Estados Unidos',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vaticano',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis y Futuna',
 u'ws': u'Samoa',
 u'ye': u'Yemen',
 u'yt': u'Mayotte',
 u'za': u'Sud\xe1frica',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}
